
from . import client
from . import config
from . import document
from . import search
from . import system
from . import version
from . import visit


stars = """
 ..   . *      .     .   * *. .        . .  .     .  *           `         .   
*         . .         ` `  *   . . .            . **              .*    * .  ` 
     .           . .            ..     *  .               *    .   .           
                    . ..` .              *.  **    . * *  . . .     *   `      
. `  .     .. .  . . ..     .       `.              . *          *   .      .  
          *         ..  .  `    `*   `    *   `.   .    `  .. .    . *   ..    
                 ..  .   .          *     .  *        *  . *        *  .       
 *        *    .          .         *` **.       .* *.. .   *. .  `    .  . .  
.. *    . .* .            .              *   .  .*. ..*  ..    `               
       `  .      *    *  . . . . . *          .. .    .  *.         `          
"""

